can_manage_chat property

Bool? can_manage_chat
getter/setter pair

True, if the administrator can get chat event log, get chat statistics, get message statistics in channels, get channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other privilege; applicable to supergroups and channels only

Implementation

Bool? can_manage_chat;