can_restrict_members property
True, if the administrator can restrict, ban, or unban chat members; always true for channels
Implementation
Bool? can_restrict_members;
True, if the administrator can restrict, ban, or unban chat members; always true for channels
Bool? can_restrict_members;