can_send_other_messages property
True, if the user can send animations, games, stickers, and dice and use inline bots. Implies can_send_messages permissions
Implementation
Bool? can_send_other_messages;
True, if the user can send animations, games, stickers, and dice and use inline bots. Implies can_send_messages permissions
Bool? can_send_other_messages;