can_toggle_mute_new_participants property
True, if the current user can enable or disable mute_new_participants setting
Implementation
Bool? can_toggle_mute_new_participants;
True, if the current user can enable or disable mute_new_participants setting
Bool? can_toggle_mute_new_participants;