original_path property
Local path to a file from which the file is generated; may be empty if there is no such file
Implementation
string? original_path;
Local path to a file from which the file is generated; may be empty if there is no such file
string? original_path;