can_get_added_reactions property
True, if the list of added reactions is available through getMessageAddedReactions
Implementation
Bool? can_get_added_reactions;
True, if the list of added reactions is available through getMessageAddedReactions
Bool? can_get_added_reactions;