can_report_reactions property
True, if reactions on the message can be reported through reportMessageReactions
Implementation
Bool? can_report_reactions;
True, if reactions on the message can be reported through reportMessageReactions
Bool? can_report_reactions;