media_album_id property

int64? media_album_id
getter/setter pair

Unique identifier of an album this message belongs to. Only audios, documents, photos and videos can be grouped together in albums

Implementation

int64? media_album_id;