sign_messages property
True, if messages sent to the channel need to contain information about the sender. This field is only applicable to channels
Implementation
Bool? sign_messages;
True, if messages sent to the channel need to contain information about the sender. This field is only applicable to channels
Bool? sign_messages;