can_toggle_aggressive_anti_spam property
True, if aggressive anti-spam checks can be enabled or disabled in the supergroup
Implementation
Bool? can_toggle_aggressive_anti_spam;
True, if aggressive anti-spam checks can be enabled or disabled in the supergroup
Bool? can_toggle_aggressive_anti_spam;