has_aggressive_anti_spam_enabled property
True, if aggressive anti-spam checks are enabled in the supergroup. The value of this field is only available to chat administrators
Implementation
Bool? has_aggressive_anti_spam_enabled;
True, if aggressive anti-spam checks are enabled in the supergroup. The value of this field is only available to chat administrators
Bool? has_aggressive_anti_spam_enabled;